@@ -4,7 +4,7 @@ Unittests and doctests for the rdflib_django app.
 import doctest
 from django.utils import unittest
 import rdflib_django
-from rdflib_django import store, tests_store, tests_rdflib
+from rdflib_django import store, test_store, test_rdflib, test_seq, test_namespaces
 
 
 def suite():
@@ -14,6 +14,8 @@ def suite():
     s = unittest.TestSuite()
     s.addTest(doctest.DocTestSuite(rdflib_django))
     s.addTest(doctest.DocTestSuite(store))
-    s.addTest(unittest.findTestCases(tests_store))
-    s.addTest(unittest.findTestCases(tests_rdflib))
+    s.addTest(unittest.findTestCases(test_store))
+    s.addTest(unittest.findTestCases(test_rdflib))
+    s.addTest(unittest.findTestCases(test_seq))
+    s.addTest(unittest.findTestCases(test_namespaces))
     return s
